# Deno Sandbox Python SDK

Create isolated [sandboxes on Deno Deploy](https://deno.com/deploy/sandboxes) to
securely run code in a lightweight Linux microVM. You can securely run shell
scripts, spawn processes, execute JavaScript applications and REPLs, and
interact with files remotely.

This Python SDK let's you create and manage sandboxes programmatically.

## Installation

```sh
uv add deno-sandbox
```

## Quick Start

TODO

## License

`MIT`, see the [LICENSE file](./LICENSE)
